@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -258,6 +259,7 @@ class BaseApi(api_client.Api):
         custom_redirect: typing.Optional[str] = None,
         reconnect: typing.Optional[str] = None,
         connection_type: typing.Optional[str] = None,
+        connection_portal_version: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
@@ -273,6 +275,8 @@ class BaseApi(api_client.Api):
             _body["reconnect"] = reconnect
         if connection_type is not None:
             _body["connectionType"] = connection_type
+        if connection_portal_version is not None:
+            _body["connectionPortalVersion"] = connection_portal_version
         args.body = body if body is not None else _body
         if user_id is not None:
             _query_params["userId"] = user_id
@@ -286,17 +290,18 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         """
-        Generate a redirect URI to securely login a user to the SnapTrade Connection Portal
+        Login user &amp; generate connection link
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -323,19 +328,29 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         if body is not schemas.unset:
             serialized_data = request_body_snap_trade_login_user_request_body.serialize(body, content_type)
-            _headers.add('Content-Type', content_type)
             if 'fields' in serialized_data:
                 _fields = serialized_data['fields']
             elif 'body' in serialized_data:
-                _body = serialized_data['body']    
+                _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -343,9 +358,18 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -390,12 +414,13 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _login_snap_trade_user_oapg(
         self,
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
@@ -404,7 +429,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Generate a redirect URI to securely login a user to the SnapTrade Connection Portal
+        Login user &amp; generate connection link
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -431,19 +456,29 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         if body is not schemas.unset:
             serialized_data = request_body_snap_trade_login_user_request_body.serialize(body, content_type)
-            _headers.add('Content-Type', content_type)
             if 'fields' in serialized_data:
                 _fields = serialized_data['fields']
             elif 'body' in serialized_data:
-                _body = serialized_data['body']    
+                _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -476,6 +511,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class LoginSnapTradeUser(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
@@ -489,7 +525,9 @@ class LoginSnapTradeUser(BaseApi):
         custom_redirect: typing.Optional[str] = None,
         reconnect: typing.Optional[str] = None,
         connection_type: typing.Optional[str] = None,
+        connection_portal_version: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -505,10 +543,12 @@ class LoginSnapTradeUser(BaseApi):
             custom_redirect=custom_redirect,
             reconnect=reconnect,
             connection_type=connection_type,
+            connection_portal_version=connection_portal_version,
         )
         return await self._alogin_snap_trade_user_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def login_snap_trade_user(
@@ -521,6 +561,7 @@ class LoginSnapTradeUser(BaseApi):
         custom_redirect: typing.Optional[str] = None,
         reconnect: typing.Optional[str] = None,
         connection_type: typing.Optional[str] = None,
+        connection_portal_version: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -536,6 +577,7 @@ class LoginSnapTradeUser(BaseApi):
             custom_redirect=custom_redirect,
             reconnect=reconnect,
             connection_type=connection_type,
+            connection_portal_version=connection_portal_version,
         )
         return self._login_snap_trade_user_oapg(
             body=args.body,
@@ -555,7 +597,9 @@ class ApiForpost(BaseApi):
         custom_redirect: typing.Optional[str] = None,
         reconnect: typing.Optional[str] = None,
         connection_type: typing.Optional[str] = None,
+        connection_portal_version: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -571,10 +615,12 @@ class ApiForpost(BaseApi):
             custom_redirect=custom_redirect,
             reconnect=reconnect,
             connection_type=connection_type,
+            connection_portal_version=connection_portal_version,
         )
         return await self._alogin_snap_trade_user_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def post(
@@ -587,6 +633,7 @@ class ApiForpost(BaseApi):
         custom_redirect: typing.Optional[str] = None,
         reconnect: typing.Optional[str] = None,
         connection_type: typing.Optional[str] = None,
+        connection_portal_version: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -602,6 +649,7 @@ class ApiForpost(BaseApi):
             custom_redirect=custom_redirect,
             reconnect=reconnect,
             connection_type=connection_type,
+            connection_portal_version=connection_portal_version,
         )
         return self._login_snap_trade_user_oapg(
             body=args.body,
