@@ -13,11 +13,8 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.security_type import SecurityType
 from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 class RequiredExcludedAsset(TypedDict):
