@@ -13,14 +13,12 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.action import Action
-from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.manual_trade_symbol import ManualTradeSymbol
 from snaptrade_client.type.order_type import OrderType
 from snaptrade_client.type.price import Price
-from snaptrade_client.type.time_in_force import TimeInForce
 
 class RequiredManualTrade(TypedDict):
     pass
@@ -32,13 +30,14 @@ class OptionalManualTrade(TypedDict, total=False):
 
     order_type: OrderType
 
-    time_in_force: TimeInForce
+    # Trade time in force examples:   * FOK - Fill Or Kill   * Day - Day   * GTC - Good Til Canceled   * GTD - Good Til Date 
+    time_in_force: str
 
     symbol: ManualTradeSymbol
 
     action: Action
 
-    # Trade Units
+    # Trade Units. Cannot work with notional value.
     units: typing.Union[int, float]
 
     price: Price
